﻿using System;
using System.ComponentModel;
using System.Runtime.CompilerServices;

namespace VSMPrototypePattern.Models
{
    public abstract class BaseModel<T> : INotifyPropertyChanged, IShallowCloneable<T>
        where T: class
    {
        public event PropertyChangedEventHandler PropertyChanged;

        protected void NotifyPropertyChanged([CallerMemberName] String propertyName = "")
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        public virtual T ShallowClone()
        {
            return (T) MemberwiseClone();
        }
    }
}
